@@ -51,6 +51,7 @@ class encryptContentPlugin(BasePlugin):
         ('encryption_info_message', mkdocs.config.config_options.Type(string_types, default=str(settings['encryption_info_message']))),
         ('global_password', mkdocs.config.config_options.Type(string_types, default=None)),
         ('password', mkdocs.config.config_options.Type(string_types, default=None)),
+        ('arithmatex', mkdocs.config.config_options.Type(bool, default=False)),
         ('hljs', mkdocs.config.config_options.Type(bool, default=False)),
         ('remember_password', mkdocs.config.config_options.Type(bool, default=False)),
         ('disable_cookie_protection', mkdocs.config.config_options.Type(bool, default=False)),
@@ -99,6 +100,7 @@ class encryptContentPlugin(BasePlugin):
             'ciphertext_bundle': b';'.join(ciphertext_bundle).decode('ascii'),
             'js_libraries': JS_LIBRARIES,
             # enable / disable features
+            'arithmatex': self.arithmatex,
             'hljs': self.hljs,
             'remember_password': self.remember_password,
             'disable_cookie_protection': self.disable_cookie_protection,
@@ -134,7 +136,7 @@ class encryptContentPlugin(BasePlugin):
         # Check if decryption_failure_message description is set on plugin configuration to overwrite
         decryption_failure_message = plugin_config.get('decryption_failure_message')
         setattr(self, 'decryption_failure_message', decryption_failure_message)
-        # Check if encryption_info_message descruption is set on plugin configuration to overwrite
+        # Check if encryption_info_message description is set on plugin configuration to overwrite
         encryption_info_message = plugin_config.get('encryption_info_message')
         setattr(self, 'encryption_info_message', encryption_info_message)
         # Check if hljs feature need to be enabled, based on theme configuration
@@ -143,6 +145,10 @@ class encryptContentPlugin(BasePlugin):
             highlightjs = config['theme']._vars['highlightjs']       
             if highlightjs:
                 setattr(self, 'hljs', highlightjs)
+        # Check if pymdownx.arithmatex feature need to be enabled, based on markdown_extensions configuration
+        setattr(self, 'arithmatex', None)
+        if 'pymdownx.arithmatex' in config['markdown_extensions']:
+            setattr(self, 'arithmatex', True)
         # Check if tag_encrypted_page feature is enable: add an extra attribute `encrypted` is add on page object
         setattr(self, 'tag_encrypted_page', False)
         if 'tag_encrypted_page' in plugin_config.keys():
@@ -173,7 +179,6 @@ class encryptContentPlugin(BasePlugin):
             encrypted_something = self.config.get('encrypted_something')
             setattr(self, 'encrypted_something', encrypted_something)
 
-
     def on_page_markdown(self, markdown, page, config, **kwargs):
         """
         The page_markdown event is called after the page's markdown is loaded from file and 
@@ -189,7 +194,7 @@ class encryptContentPlugin(BasePlugin):
         """
         if 'password' in page.meta.keys():
             page_password = page.meta.get('password')
-            # If global_password is set, but you dont want to encrypt content
+            # If global_password is set, but you don't want to encrypt content
             if page_password == '':
                 setattr(self, 'password', None)
             else:
@@ -244,16 +249,18 @@ class encryptContentPlugin(BasePlugin):
                 #print({'name': name, 'html tag': tag[0], 'type': tag[1]})
                 something_search = soup.findAll(tag[0], { tag[1]: name })
                 if something_search is not None and len(something_search) > 0:
-                    # Loop for multi childs tags on target element
+                    # Loop for multi child tags on target element
                     for item in something_search:
                         # Remove '\n', ' ' useless content generated by bs4 parsing...
                         item.contents = [content for content in item.contents if not content in ['\n', ' ']]
                         # Merge the content in case there are several elements
                         if len(item.contents) > 1:
                             merge_item = ''.join([str(s) for s in item.contents])
-                        else:
+                        elif len(item.contents) == 1:
                             merge_item = item.contents[0]
-                        # Encrypt childs items on target tags with page password
+                        else:
+                            merge_item = ""
+                        # Encrypt child items on target tags with page password
                         cipher_bundle = self.__encrypt_text_aes__(merge_item, page.password)
                         encrypted_content = b';'.join(cipher_bundle).decode('ascii')
                         # Replace initial content with encrypted one
@@ -267,4 +274,4 @@ class encryptContentPlugin(BasePlugin):
                         else:
                             item['style'] = "display:none"
             output_content = str(soup)
-        return output_content
\ No newline at end of file
+        return output_content
